#
#  PiconOledDisplay E2
#
#  $Id: plugin.py,v 1.2 2010-10-24 20:45:31 dr_best Exp $
#
#  Coded by Dr.Best (c) 2010
#  Support: www.dreambox-tools.info
#
#  This plugin is licensed under the Creative Commons 
#  Attribution-NonCommercial-ShareAlike 3.0 Unported 
#  License. To view a copy of this license, visit
#  http://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter to Creative
#  Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
#
#  Alternatively, this plugin may be distributed and executed on hardware which
#  is licensed by Dream Multimedia GmbH.

#  This plugin is NOT free software. It is open source, you are allowed to
#  modify it (if you keep the license), but it may not be commercially 
#  distributed other than under the conditions noted above.
#

from Plugins.Plugin import PluginDescriptor
from Screens.InfoBarGenerics import InfoBarSummarySupport
from Screens.Screen import Screen
from Components.config import config, ConfigSubsection, ConfigBoolean, getConfigListEntry
from Components.ConfigList import ConfigListScreen
from Screens.Standby import TryQuitMainloop
from Screens.MessageBox import MessageBox
from Components.Sources.StaticText import StaticText
from Components.ActionMap import ActionMap

# for localized messages
from . import _

config.plugins.piconinoled = ConfigSubsection()
config.plugins.piconinoled.enabled = ConfigBoolean(True)

class ConfigPiconOledDisplay(ConfigListScreen, Screen):
	skin = """
		<screen name="ConfigPiconOledDisplay" position="center,center" size="560,110">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="140,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="280,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="420,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<widget render="Label" source="key_red" position="0,0" size="140,40" zPosition="5" valign="center" halign="center" backgroundColor="red" font="Regular;21" transparent="1" foregroundColor="white" shadowColor="black" shadowOffset="-1,-1" />
			<widget render="Label" source="key_green" position="140,0" size="140,40" zPosition="5" valign="center" halign="center" backgroundColor="red" font="Regular;21" transparent="1" foregroundColor="white" shadowColor="black" shadowOffset="-1,-1" />
			<widget name="config" position="20,50" size="520,50" scrollbarMode="showOnDemand" />
		</screen>"""

	def __init__(self, session):
		Screen.__init__(self, session)
		self.title = _("Picon display in OLED Setup")
		self["actions"] = ActionMap(["SetupActions", "ColorActions"],
		{
			"green": self.keySave,
			"red": self.keyClose,
			"cancel": self.keyClose,
		}, -2)
		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("OK"))
		self.list = []
		self.list.append(getConfigListEntry(_("Enable picon display in oled"), config.plugins.piconinoled.enabled))
		ConfigListScreen.__init__(self, self.list, session = session)


	def keySave(self):
		for x in self["config"].list:
			x[1].save()
		restartbox = self.session.openWithCallback(self.restartGUI,MessageBox,_("GUI needs a restart to apply to new settings.\nDo you want to Restart the GUI now?"), MessageBox.TYPE_YESNO)
		restartbox.setTitle(_("Restart GUI now?"))	

	def restartGUI(self, answer):
		if answer is True:
			self.session.open(TryQuitMainloop, 3)
		else:
			self.close()

	def keyClose(self):
		for x in self["config"].list:
			x[1].cancel()
		self.close()

def autostart(session, **kwargs):
	if config.plugins.piconinoled.enabled.value:
		from os import path as os_path
		from enigma import eEnv
		available = False
		searchPaths = (eEnv.resolve('${datadir}/enigma2/%s/'),
					'/media/cf/%s/',
					'/media/usb/%s/')
		oled_path = "picon_oled"
		oledpath = ""
		for path in searchPaths:
			oledpath = (path % oled_path)
			if os_path.exists(oledpath):
				available = True
				break			
		if available:	
			print "[InfoBarSummarySupport] using picon-oled-display plugin with path = %s" % oledpath
			InfoBarSummarySupport.createSummary = createSummaryOLED
		else:
			print "[InfoBarSummarySupport] picon-oled-display plugin enabled, but no oled picons found..."

def createSummaryOLED(self):
	return InfoBarSummaryPicon

class InfoBarSummaryPicon(Screen):
	skin = """
	<screen position="0,0" size="96,64" id="2">
		<widget source="session.CurrentService" render="Picon" position="0,0" size="96,64" path="picon_oled" >
			<convert type="ServiceName">Reference</convert>
		</widget>
	</screen>"""	

def setup(session, **kwargs):
	session.open(ConfigPiconOledDisplay) # start setup

def startSetup(menuid):
	if menuid != "merlin": # show setup only in merlin level menu
		return []
	return [(_("Picon display in OLED Setup"), setup, "piconinoledsetup", 41)]

def Plugins(**kwargs):
	list = [PluginDescriptor(where = [PluginDescriptor.WHERE_SESSIONSTART], fnc=autostart)]
	list.append(PluginDescriptor(name="PiconInOled-Setup", description=_("Picon display in OLED"), where = [PluginDescriptor.WHERE_MENU], fnc=startSetup))
	return list

